@@ -654,6 +654,7 @@ void KCalculator::setupKeys() {
 	mem_button_list_.append(pbMemClear);
 	mem_button_list_.append(pbClear);
 	mem_button_list_.append(pbAllClear);
+	mem_button_list_.append(pbBackspace);
 
 	operation_button_list_.append(pbMultiplication);
 	operation_button_list_.append(pbParenOpen);
@@ -1515,11 +1516,11 @@ void KCalculator::slotStatStdDevclicked() {
 
 	if (shift_mode_) {
 		// std (n-1)
-		core.StatStdDeviation(KNumber::Zero);
+		core.StatStdSample(KNumber::Zero);
 		pbShift->setChecked(false);
 	} else {
 		// std (n)
-		core.StatStdSample(KNumber::Zero);
+		core.StatStdDeviation(KNumber::Zero);
 	}
 
 	updateDisplay(UPDATE_FROM_CORE);
@@ -1533,10 +1534,8 @@ void KCalculator::slotStatStdDevclicked() {
 void KCalculator::slotStatMedianclicked() {
 
 	if (!shift_mode_) {
-		// std (n-1)
 		core.StatMedian(KNumber::Zero);
 	} else {
-		// std (n)
 		core.StatMedian(KNumber::Zero);
 		pbShift->setChecked(false);
 	}
@@ -1762,7 +1761,6 @@ void KCalculator::slotSetSimpleMode() {
 	pbSquare->hide();
 	pbPower->hide();
 	pbCube->hide();
-	pbBackspace->hide();
 	pbEE->hide();
 
 	// delete the constant menu since it doesn't fit
@@ -1793,7 +1791,6 @@ void KCalculator::slotSetScienceMode() {
 	pbSquare->show();
 	pbPower->show();
 	pbCube->show();
-	pbBackspace->show();
 	pbEE->show();
 
 	// show or hide some groups of buttons
@@ -1831,7 +1828,6 @@ void KCalculator::slotSetStatisticMode() {
 	pbSquare->show();
 	pbPower->show();
 	pbCube->show();
-	pbBackspace->show();
 	pbEE->show();
 
 	// show or hide some groups of buttons
@@ -1870,7 +1866,6 @@ void KCalculator::slotSetNumeralMode() {
 	pbSquare->show();
 	pbPower->show();
 	pbCube->show();
-	pbBackspace->show();
 	pbEE->show();
 
 	// show or hide some groups of buttons
