@@ -22,12 +22,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // Workaround: include before gmp.h to fix build with gcc-4.9
 #include <cstddef>
 #include <gmp.h>
-
-#ifdef KNUMBER_USE_MPFR
 #include <mpfr.h>
-#endif
 
-#include <QtGlobal>
 #include <QString>
 
 namespace detail {
